.. manually constructed -- removed several low-level packages

nltk Package
============

:mod:`nltk` Package
-------------------

.. automodule:: nltk.__init__
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`collocations` Module
--------------------------

.. automodule:: nltk.collocations
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`data` Module
------------------

.. automodule:: nltk.data
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`downloader` Module
------------------------

.. automodule:: nltk.downloader
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`featstruct` Module
------------------------

.. automodule:: nltk.featstruct
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`grammar` Module
---------------------

.. automodule:: nltk.grammar
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`help` Module
------------------

.. automodule:: nltk.help
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`probability` Module
-------------------------

.. automodule:: nltk.probability
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`text` Module
------------------

.. automodule:: nltk.text
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`toolbox` Module
---------------------

.. automodule:: nltk.toolbox
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`translate` Module
-----------------------

.. automodule:: nltk.translate
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`tree` Module
------------------

.. automodule:: nltk.tree
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`treetransforms` Module
----------------------------

.. automodule:: nltk.treetransforms
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`util` Module
------------------

.. automodule:: nltk.util
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`wsd` Module
------------------

.. automodule:: nltk.wsd
    :members:
    :undoc-members:
    :show-inheritance:


Subpackages
-----------

.. toctree::

    nltk.app
    nltk.ccg
    nltk.chat
    nltk.chunk
    nltk.classify
    nltk.cluster
    nltk.corpus
    nltk.draw
    nltk.inference
    nltk.metrics
    nltk.misc
    nltk.parse
    nltk.sem
    nltk.stem
    nltk.tag
    nltk.test
    nltk.tokenize
